
# Slot: happens_during

Optional extension describing where the BP takes place

URI: [gocam:biologicalProcessAssociation__happens_during](https://w3id.org/gocam/biologicalProcessAssociation__happens_during)


## Domain and Range

None &#8594;  <sub>0..1</sub> [PhaseTermObject](PhaseTermObject.md)

## Parents


## Children


## Used by

 * [BiologicalProcessAssociation](BiologicalProcessAssociation.md)
